@@ -1,9 +1,13 @@
 """Global config file of jazzy package."""
 # src/jazzy/config.py
 
+MINIMISATION_METHOD = None
+ROUNDING_DIGITS = 4
+ANNOTATION_FONT_SCALE = 0.7
+
 
 class Config(object):
-    """Golbal config object.
+    """Global config object.
 
     Global jazzy config file for command-line interface (CLI).
     Passable to CLI methods via '@pass_config' decorator.
